pub async fn activate(target: &ActivationTarget) -> Result<ActivationOutcome>Expand description
High-level activate facade — production callers use DEFAULT_BACKEND.
Test paths that need a stub backend call activate_with directly.
pub async fn activate(target: &ActivationTarget) -> Result<ActivationOutcome>High-level activate facade — production callers use DEFAULT_BACKEND.
Test paths that need a stub backend call activate_with directly.